diff mbox series

[Xen-devel,OSSTEST,17/62] stretch: Use chainloading when booting using GRUB on Arm64

Message ID 20190410142408.22848-18-ian.jackson@eu.citrix.com
State New
Headers show
Series None | expand

Commit Message

Ian Jackson April 10, 2019, 2:23 p.m. UTC
From: Julien Grall <julien.grall@arm.com>

The GRUB package in stretch is not able to boot Xen on Arm64.
Use chainloading as we did for jessie for the time being.

Note that a bug has been filled on Debian to integrate Xen
pactches for the next release (see [1]).

[1] https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=884770

Signed-off-by: Julien Grall <julien.grall@arm.com>
Signed-off-by: Wei Liu <wei.liu2@citrix.com>
Acked-by: Ian Jackson <ian.jackson@eu.citrix.com>
---
v4: Correct suite name capitalisation in commit message and comment.
---
 Osstest/Debian.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/Osstest/Debian.pm b/Osstest/Debian.pm
index 85b1890d..80b4cf37 100644
--- a/Osstest/Debian.pm
+++ b/Osstest/Debian.pm
@@ -435,10 +435,10 @@  sub setupboot_grub2 ($$$$) {
     my $rmenu= '/boot/grub/grub.cfg';
     my $kernkey= (defined $xenhopt ? 'KernDom0' : 'KernOnly');
 
     # Grub2 on Jessie/arm* doesn't do multiboot, so we must chainload.
     my $need_uefi_chainload =
         get_host_property($ho, "firmware", "") eq "uefi" &&
-        $ho->{Suite} =~ m/jessie/ && $r{arch} =~ m/^arm/;
+        $ho->{Suite} =~ m/jessie|stretch/ && $r{arch} =~ m/^arm/;
 
     my $parsemenu= sub {
         my $f= bl_getmenu_open($ho, $rmenu, "$stash/$ho->{Name}--grub.cfg.1");
@@ -435,10 +435,10 @@  sub setupboot_grub2 ($$$$) {
     my $kernkey= (defined $xenhopt ? 'KernDom0' : 'KernOnly');
 
-    # Grub2 on Jessie/arm* doesn't do multiboot, so we must chainload.
+    # Grub2 on jessie/stretch ARM* doesn't do multiboot, so we must chainload.
     my $need_uefi_chainload =
         get_host_property($ho, "firmware", "") eq "uefi" &&